pub async fn get_competitive_pricing(
    configuration: &Configuration,
    marketplace_id: &str,
    item_type: &str,
    asins: Option<Vec<String>>,
    skus: Option<Vec<String>>,
    customer_type: Option<&str>
) -> Result<GetPricingResponse, Error>
Returns competitive pricing information for a seller’s offer listings based on seller SKU or ASIN. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.5 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.