Function amazon_sp_product_pricing::apis::product_pricing_api::get_item_offers
source · [−]pub async fn get_item_offers(
configuration: &Configuration,
marketplace_id: &str,
item_condition: &str,
asin: &str,
customer_type: Option<&str>
) -> Result<GetOffersResponse, Error>Expand description
Returns the lowest priced offers for a single item based on ASIN. Usage Plan: | Rate (requests per second) | Burst | | –– | –– | | 0.5 | 1 | The x-amzn-RateLimit-Limit response header returns the usage plan rate limits that were applied to the requested operation, when available. The table above indicates the default rate and burst values for this operation. Selling partners whose business demands require higher throughput may see higher rate and burst values than those shown here. For more information, see Usage Plans and Rate Limits in the Selling Partner API.